      SUBROUTINE SNOPAC (ETP,ETA,PRCP,PRCP1,SNOWNG,SMC,SMCMAX,SMCWLT,
     &  SMCREF, SMCDRY, CMC, CMCMAX, NSOIL, DT, SBETA, Q1,
     &  Q2,T1,SFCTMP,T24,TH2,F,F1,S,STC,EPSCA,SFCPRS,
     &  B, PC, RCH, RR, CFACTR, SALP, ESD,
     +  SNOWH, SH2O, SLOPE, KDT, FRZFACT, PSISAT,SNUP,
     &  ZSOIL, DWSAT, DKSAT, TBOT, ZBOT, SHDFAC, RUNOFF1,
     &  RUNOFF2,RUNOFF3,EDIR1,EC1,ETT1,NROOT,SNMAX,ICE,
     &  RTDIS,QUARTZ, FXEXP,CSOIL,FLX1,FLX2,FLX3)

      IMPLICIT NONE

C ----------------------------------------------------------------------
CC    PURPOSE:  TO CALCULATE SOIL MOISTURE AND HEAT FLUX VALUES & UPDATE
CC    =======   SOIL MOISTURE CONTENT AND SOIL HEAT CONTENT VALUES FOR
CC              THE CASE WHEN A SNOW PACK IS PRESENT.
C ----------------------------------------------------------------------

      INTEGER ICE
      INTEGER NROOT
      INTEGER NSOIL

      LOGICAL SNOWNG

      REAL B
      REAL BETA
      REAL CFACTR
      REAL CMC
      REAL CMCMAX
      REAL CP
      REAL CPH2O
      REAL CPICE
      REAL CSOIL
      REAL DENOM
      REAL DEW
      REAL DF1
      REAL DKSAT
      REAL DRIP
      REAL DSOIL
      REAL DTOT
      REAL DT
      REAL DWSAT
      REAL EC
      REAL EDIR
      REAL EPSCA
      REAL ESD
      REAL EXPSNO
      REAL EXPSOI
      REAL ETA
      REAL ETA1
      REAL ETP
      REAL ETP1
      REAL ETP2
      REAL ETT
      REAL EX
      REAL EXPFAC
      REAL F
      REAL FXEXP
      REAL FLX1
      REAL FLX2
      REAL FLX3
      REAL F1
      REAL KDT
      REAL LSUBF
      REAL LSUBC
      REAL LSUBS
      REAL PC
      REAL PRCP
      REAL PRCP1
      REAL Q1
      REAL Q2
      REAL RCH
      REAL RIB
      REAL RR
      REAL RTDIS   ( NSOIL )
      REAL RUNOFF
      REAL S
      REAL SBETA
      REAL S1
      REAL SFCTMP
      REAL SHDFAC
      REAL SIGMA
      REAL SMC     ( NSOIL )
      REAL SH2O    ( NSOIL )
      REAL SMCDRY
      REAL SMCMAX
      REAL SMCREF
      REAL SMCWLT
      REAL SNMAX
      REAL SNOWH
      REAL STC     ( NSOIL )
      REAL T1
      REAL T11
      REAL T12
      REAL T12A
      REAL T12B
      REAL T24
      REAL TBOT
      REAL ZBOT
      REAL TH2
      REAL YY
      REAL ZSOIL( NSOIL )
      REAL ZZ1
C
      REAL TFREEZ, SALP, SFCPRS, SLOPE, FRZFACT, PSISAT, SNUP
      REAL RUNOFF1, RUNOFF2, RUNOFF3,RUNOXX3
      REAL EDIR1, EC1, ETT1, QUARTZ
      REAL SNDENS, SNCOND, RSNOW, SNCOVER, QSAT, ETP3, SEH, T14
      REAL CSNOW

      COMMON/RITE/ BETA,DRIP,EC,EDIR,ETT,RUNOFF,
     &  DEW,RIB,RUNOXX3
     
      PARAMETER(CP=1004.5,CPH2O=4.218E+3,CPICE=2.106E+3,
     &  LSUBF=3.335E+5,LSUBC=2.501000E+6,LSUBS=2.83E+6,SIGMA=5.67E-8)

      PARAMETER ( TFREEZ = 273.15)

C ----------------------------------------------------------------------
C EXECUTABLE CODE BEGINS HERE...
C CONVERT POTENTIAL EVAP (ETP) FROM KG M-2 S-1 TO M S-1 AND THEN TO AN
C AMOUNT (M) GIVEN TIMESTEP (DT) AND CALL IT AN EFFECTIVE SNOWPACK
C REDUCTION AMOUNT, ETP2 (M).  THIS IS THE AMOUNT THE SNOWPACK WOULD BE
C REDUCED DUE TO EVAPORATION FROM THE SNOW SFC DURING THE TIMESTEP.
C EVAPORATION WILL PROCEED AT THE POTENTIAL RATE UNLESS THE SNOW DEPTH
C IS LESS THAN THE EXPECTED SNOWPACK REDUCTION.
C IF SEAICE (ICE=1), BETA REMAINS=1.
C ----------------------------------------------------------------------
      PRCP1 = PRCP1*0.001
      ETP2 = ETP * 0.001 * DT
      BETA = 1.0
      IF(ICE .NE. 1) THEN
        IF (ESD .LT. ETP2) THEN
          BETA = ESD / ETP2
        ENDIF
      ENDIF

C ----------------------------------------------------------------------
C IF ETP<0 (DOWNWARD) THEN DEWFALL (=FROSTFALL IN THIS CASE).
C ----------------------------------------------------------------------
      DEW = 0.0
      IF (ETP .LT. 0.0) THEN
        DEW = -ETP * 0.001
      ENDIF

C ----------------------------------------------------------------------
C CALCULATE AN 'EFFECTIVE SNOW-GRND SFC TEMP' BASED ON HEAT FLUXES
C BETWEEN THE SNOW PACK AND THE SOIL AND ON NET RADIATION.
C ----------------------------------------------------------------------
      T12A = ((F - SIGMA * T24) / RCH+TH2-SFCTMP-BETA*EPSCA) / RR
            
C ----------------------------------------------------------------------
C DETERMINE SOIL THERMAL CONDUCTIVITY (DF1) BASED ON SOIL MOISTURE.
C ----------------------------------------------------------------------
      CALL TDFCND(DF1,SMC(1),QUARTZ,SMCMAX,SH2O(1))
      
C ----------------------------------------------------------------------
C REDUCTION OF SOIL THERMAL CONDUCTIVITY DUE TO OVERLYING VEGETATION.
C ----------------------------------------------------------------------
      EXPFAC = EXP(SBETA*SHDFAC)
      DF1 = DF1 * EXPFAC
      
C ----------------------------------------------------------------------
C SNOWPACK EFFECT ON THERMAL CONDUCTIVITY.
C DETERMINE SNOW DENSITY, SNOW CONDUCTIVITY (VIA FUNCTION), AND
C EFFECTIVE CONDUCTIVITY USING GEOMETRIC MEAN WEIGHTING OF SOIL AND
C SNOWPACK. 
C ----------------------------------------------------------------------
      SNDENS = ESD/SNOWH
      SNCOND = CSNOW(SNDENS)
      DSOIL = -(0.5 * ZSOIL(1))
      DTOT = SNOWH + DSOIL
      EXPSNO = SNOWH/DTOT
      EXPSOI = DSOIL/DTOT
      DF1 = (SNCOND**EXPSNO)*(DF1**EXPSOI)
      
C ----------------------------------------------------------------------
C CALCULATE A NEW SNOW-GRND SFC TEMP (T12B) USING UPDATED DF1, THEN A
C FINAL SNOW-GRND SFC TEMP (T12) USING SFCTMP, T12A, T12B.  RECALCULATE
C THE SOIL HEAT FLUX (INTO OR OUT OF THE SOIL) USING NEW T12 AND DF1. 
C ----------------------------------------------------------------------
      T12B = DF1 * STC(1) / ( DTOT * RR * RCH )
      DENOM = 1.0 + DF1 / ( DTOT * RR * RCH )
      T12 = (SFCTMP + T12A + T12B ) / DENOM      
      S = DF1 * ( T12 - STC(1) ) / ( DTOT )

C ----------------------------------------------------------------------
C IF THE 'EFFECTIVE SNOW-GRND SFC TEMP' IS AT OR BELOW FREEZING, NO SNOW
C MELT WILL OCCUR.  SET THE SKIN TEMP TO THIS EFFECTIVE TEMP AND SET THE
C EFFECTIVE PRECIP TO ZERO.
C ----------------------------------------------------------------------
      IF (T12 .LE. TFREEZ) THEN
        ESD = MAX(0.0, ESD-ETP2)
        T1 = T12
        FLX3 = 0.0
        EX = 0.0
        SNMAX = 0.0

C ----------------------------------------------------------------------
C IF THE 'EFFECTIVE SNOW-GRND SFC TEMP' IS ABOVE FREEZING, SNOW MELT
C WILL OCCUR.  CALL THE SNOW MELT RATE,EX AND AMT, SNMAX.  REVISE THE
C EFFECTIVE SNOW DEPTH.  REVISE THE SKIN TEMP BECAUSE IT WOULD HAVE CHGD
C DUE TO THE LATENT HEAT RELEASED BY THE MELTING. CALC THE LATENT HEAT
C RELEASED, FLX3. SET THE EFFECTIVE PRECIP, PRCP1 TO THE SNOW MELT RATE,
C EX FOR USE IN SMFLX.  ADJUSTMENT TO T1 TO ACCOUNT FOR SNOW PATCHES.
C ----------------------------------------------------------------------
      ELSE
        IF ( (SNUP .GT. 0.0) .AND. (ESD .LT. SNUP) ) THEN
          RSNOW = ESD / SNUP
          SNCOVER = 1.- (EXP(-SALP*RSNOW)-RSNOW*EXP(-SALP))
        ELSE
          SNCOVER = 1.
        ENDIF  
        T1 = TFREEZ * SNCOVER + T12 * ( 1.0 - SNCOVER )
        QSAT = (0.622*6.11E2)/(SFCPRS-0.378*6.11E2)
        ETP = RCH*(QSAT-Q2)/CP
        ETP2 = ETP*0.001*DT
        BETA = 1.0
	
C ----------------------------------------------------------------------
C IF POTENTIAL EVAP (SUBLIMATION) GREATER THAN DEPTH OF SNOWPACK.
C BETA<1
C ----------------------------------------------------------------------
        IF ( ESD .LE. ETP2 ) THEN
          BETA = ESD / ETP2
          ESD = 0.0
          SNMAX = 0.0
          EX = 0.0
	  
C ----------------------------------------------------------------------
C POTENTIAL EVAP (SUBLIMATION) LESS THAN DEPTH OF SNOWPACK, BETA=1.
C SNOWPACK (ESD) REDUCED BY POT EVAP RATE
C ETP3 (CONVERT TO FLUX)
C UPDATE SOIL HEAT FLUX BECAUSE T1 PREVIOUSLY CHANGED.
C SNOWMELT REDUCTION DEPENDING ON SNOW COVER
C IF SNOW COVER LESS THAN 5% NO SNOWMELT REDUCTION
C ----------------------------------------------------------------------
        ELSE
          ESD = MAX(0.0, ESD-ETP2)
          ETP3 = ETP*LSUBC
          S = DF1 * ( T1 - STC(1) ) / ( DTOT )
          SEH = RCH*(T1-TH2)
          T14 = T1*T1
          T14 = T14*T14
          FLX3 = F - SIGMA*T14 - S - SEH - ETP3
          IF(FLX3.LE.0.0) FLX3=0.0
          EX = FLX3*0.001/LSUBF
          IF ( SNCOVER .GT. 0.05) EX = EX * SNCOVER
          SNMAX = EX * DT
        ENDIF
        
C ----------------------------------------------------------------------
C SNMAX.LT.ESD
C ELSE
C ----------------------------------------------------------------------
        IF(SNMAX.LT.ESD) THEN
          ESD = ESD - SNMAX
        ELSE
          EX = ESD/DT
          SNMAX = ESD
          ESD = 0.0
          FLX3 = EX*1000.0*LSUBF
        ENDIF
        PRCP1 = PRCP1 + EX

      ENDIF
         
C ----------------------------------------------------------------------
C SET THE EFFECTIVE POTNL EVAPOTRANSP (ETP1) TO ZERO SINCE SNOW CASE SO
C SURFACE EVAP NOT CALCULATED FROM EDIR, EC, OR ETT IN SMFLX (BELOW).
C IF SEAICE (ICE=1) SKIP CALL TO SMFLX.
C SMFLX RETURNS SOIL MOISTURE VALUES AND PRELIMINARY VALUES OF
C EVAPOTRANSPIRATION.  IN THIS, THE SNOW PACK CASE, THE PRELIM VALUES
C (ETA1) ARE NOT USED IN SUBSEQUENT CALCULATION OF EVAP.
C NEW STATES ADDED: SH2O, AND FROZEN GROUND CORRECTION FACTOR
C EVAP EQUALS POTENTIAL EVAP UNLESS BETA<1.
C ----------------------------------------------------------------------
      ETP1 = 0.0
      IF (ICE .NE. 1) THEN
        CALL SMFLX ( ETA1,SMC,NSOIL,CMC,ETP1,DT,PRCP1,ZSOIL,
     +    SH2O, SLOPE, KDT, FRZFACT,
     &    SMCMAX,B,PC,SMCWLT,DKSAT,DWSAT,
     &    SMCREF,SHDFAC,CMCMAX,SMCDRY,CFACTR,RUNOFF1,RUNOFF2,
     &    RUNOFF3, EDIR1, EC1, ETT1,SFCTMP,Q2,NROOT,RTDIS,
     &    FXEXP)

      ENDIF
      ETA = BETA*ETP

C ----------------------------------------------------------------------
C UPDATED SURFACE/SOIL TEMP DIFFUSIVITY/CONDUCTIVITY GIVEN UPDATED SOIL
C MOISTURE (SMC).
C REDUCTION OF SOIL THERMAL CONDUCTIVITY DUE TO OVERLYING VEGETATION.
C SNOWPACK EFFECT ON THERMAL CONDUCTIVITY:  UPDATE SNOW DENSITY USING
C UPDATED ESD THEN CALCULATE NEW SNOW CONDUCTIVITY (VIA FUNCTION), AND
C EFFECTIVE CONDUCTIVITY USING GEOMETRIC MEAN WEIGHTING OF SOIL AND
C SNOWPACK. 
C ----------------------------------------------------------------------
      CALL TDFCND(DF1,SMC(1),QUARTZ,SMCMAX,SH2O(1))
      DF1 = DF1 * EXPFAC
      SNDENS = ESD/SNOWH
      SNCOND = CSNOW(SNDENS)
      DF1 = (SNCOND**EXPSNO)*(DF1**EXPSOI)

C ----------------------------------------------------------------------
C IF SEAICE, SET DF1=2.2 (FIXED CONSTANT VALUE)
C ----------------------------------------------------------------------
      IF(ICE.EQ.1) DF1 = 2.2

C ----------------------------------------------------------------------
C THE 'ADJUSTED TOP SOIL LYR TEMP' (YY) AND THE 'ADJUSTED SOIL HEAT
C FLUX' (ZZ1) ARE SET TO THE TOP SOIL LYR TEMP, AND 1, RESPECTIVELY.
C THESE ARE CLOSE-ENOUGH APPROXIMATIONS BECAUSE THE SFC HEAT FLUX TO BE
C COMPUTED IN SHFLX WILL EFFECTIVELY BE THE FLUX AT THE SNOW TOP
C SURFACE.  T11 IS A DUMMY ARGUEMENT SINCE WE WILL NOT USE ITS VALUE AS
C REVISED BY SHFLX.
C ----------------------------------------------------------------------
      ZZ1 = 1.0
      YY = STC(1)-0.5*S*ZSOIL(1)*ZZ1/DF1
      T11 = T1

C ----------------------------------------------------------------------
C SNOW DEPTH AND DENSITY ADJUSTMENT BASED ON SNOW COMPACTION.
C ----------------------------------------------------------------------
      CALL SNOWPACK(ESD,DT,SNOWH,SNDENS,T1,YY)

C ----------------------------------------------------------------------
C SHFLX WILL CALC/UPDATE THE SOIL TEMPS.  NOTE:  THE SUB-SFC HEAT FLUX 
C (S1) AND THE SKIN TEMP (T11) OUTPUT FROM THIS SHFLX CALL ARE NOT USED 
C IN ANY SUBSEQUENT CALCULATIONS. RATHER, THEY ARE DUMMY VARIABLES HERE 
C IN THE SNOPAC CASE, SINCE THE SKIN TEMP AND SUB-SFC HEAT FLUX ARE 
C UPDATED INSTEAD NEAR THE BEGINNING OF THE NEXT CALL TO SNOPAC.
C ----------------------------------------------------------------------

      CALL SHFLX(S1,STC,SMC,SMCMAX,NSOIL,T11,DT,YY,ZZ1,ZSOIL,TBOT,
     +  ZBOT, SMCWLT, PSISAT, SH2O,
     &  B,F1,DF1,ICE, 
     &  QUARTZ,CSOIL)

C ----------------------------------------------------------------------
C IF PRECIP IS FALLING, CALC HEAT FLUX FROM SNOW SFC TO NEWLY
C ACCUMULATING PRECIP.
C ----------------------------------------------------------------------
      FLX1 = 0.0
      IF ( SNOWNG ) THEN
        FLX1 = CPICE * PRCP * ( T1 - SFCTMP )
      ELSE
        IF (PRCP .GT. 0.0) FLX1 = CPH2O * PRCP * (T1 - SFCTMP)
      ENDIF
      
      RETURN
      END
