      SUBROUTINE SNOW_NEW ( T,P,HC,DS )

      IMPLICIT NONE
      
C     CALCULATING SNOW DEPTH AND DENSITITY TO ACCOUNT FOR THE NEW SNOWFALL
C     T - AIR TEMPERATURE, K
C     P - NEW SNOWFALL, M 
C     HC - SNOW DEPTH, M
C     DS - SNOW DENSITY 
C     NEW VALUES OF SNOW DEPTH & DENSITY WILL BE RETURNED   
      
      REAL HC
      REAL T 
      REAL P
      REAL DS
      REAL H
      REAL PX
      REAL TX
      REAL DS0
      REAL HNEW
      
C     ##  CONVERSION INTO SIMULATION UNITS   ######################### 
      
      H=HC*100.
      PX=P*100.
      TX=T-273.15
      
C     ----------------------------------------------------------------------
C     ###  CALCULATING NEW SNOWFALL DENSITY DEPENDING ON TEMPERATURE      ##
C     ###  EQUATION FROM GOTTLIB L. 'A GENERAL RUNOFF MODEL FOR SNOWCOVERED
C     ###  AND GLACIERIZED BASIN', 6TH NORDIC HYDROLOGICAL CONFERENCE, 
C     ###  VEMADOLEN, SWEDEN, 1980, 172-177PP.
C-----------------------------------------------------------------------
      
      IF(TX .LE. -15.) THEN
         DS0=0.05
      ELSE                                                      
         DS0=0.05+0.0017*(TX+15.)**1.5
      ENDIF
      
C     ##   ADJUSTMENT OF SNOW DENSITY DEPENDING ON NEW SNOWFALL      
      
      HNEW=PX/DS0
      IF ((H+HNEW) .GT. 0.0) THEN
         DS=(H*DS+HNEW*DS0)/(H+HNEW)
         H=H+HNEW
      ELSE
         DS=0.0
         H=0.0
      END IF
      
      HC=H*0.01
      
      RETURN
      END
